# Electronic Annex 4: Example to the developed interface to pandapower solvers of the SciPy package  of the paper:
# Steady-state analysis of electrical networks in pandapower software: Computational performances of Newton-Raphson,
# Newton-Raphson with Iwamoto multiplier #and Gauss-Seidel methods
# Jan Vysocký, Ladislav Foltyn, Dejan Brkić, Renáta Praksová, Pavel Praks
# Available methods:
# 1 - Krylov
# 2 - Anderson
# 3 - Broyden1
# 4 - Broyden2
# 5 - Hybrid Powell Method
# 6 - Levenberg-Marquardt
# 7 - Quasilinearisation method
# 8 - Continuous Newton Method

import pp2scipy
from test_grid import make_test_grid
import pandapower as pp

# Select number of the method
num_method = 9


if num_method == 1:
    method = 'krylov'
elif num_method == 2:
    method = 'anderson'
elif num_method == 3:
    method = 'broyden1'
elif num_method == 4:
    method = 'broyden2'
elif num_method == 5:
    method = 'hybr'
elif num_method == 6:
    method = 'lm'
elif num_method == 7:
    method = 'quasi'
elif num_method == 8:
    method = 'cont_newton'
else:
    print('Wrong method number! Hybr method is set as default')
    method = 'hybr'

# Create a test grid from .py file
DS_model = make_test_grid()

pp2scipy.runpp_scipy(net=DS_model, algorithm=method, calculate_voltage_angles='auto', init='auto', max_iteration=10,
                     tolerance_mva=1e-06, trafo_model='t', trafo_loading='current', enforce_q_lims=False,
                     check_connectivity=True, voltage_depend_loads=False, consider_line_temperature=False)
