# Electronic Annex 1: The definition of the test-network model in its basic configuration
# using pandapower functions
# Jan Vysocky, Ladislav Foltyn, Dejan Brkic, Renáta Praksova, Pavel Praks

import pandapower
from pandas import read_json


def make_test_grid():
    # Create a new empty pandapower electrical network model
    DS_model = pandapower.create_empty_network(name='DS Model', f_hz=50.0, sn_mva=1, add_stdtypes=True)

    # Define the parameters of individual types of electrical power lines (the types used in the local pandapower network model)
    line_data1 = {"c_nf_per_km": 0, "r_ohm_per_km": 0.387, "x_ohm_per_km": 0.076969, "max_i_ka": 0.043924, "type": "cs", "q_mm2": 50, "alpha": 0.00403}
    pandapower.create_std_type(net=DS_model, data=line_data1, name='LVC_CYKY_4x50', element='line')

    # Define the parameters of individual types of electrical transformers (the types used in the local pandapower network model)
    trafo_data1 = {"sn_mva": 1, "vn_hv_kv": 22, "vn_lv_kv": 0.4, "vk_percent": 6, "vkr_percent": 1, "pfe_kw": 0.8, "i0_percent": 0.15, "shift_degree": 30, "tap_side": 'hv', "tap_neutral": 0, "tap_min": -2, "tap_max": 2, "tap_step_percent": 2.5, "tap_step_degree": 0, "tap_phase_shifter": False}
    pandapower.create_std_type(net=DS_model, data=trafo_data1, name='TR_type_1', element='trafo')

    # We will now create the individual network elements to be part of the pandapower network model, and in the same step, we will insert this new elements into the pandapower network model.
    # Create individual nodes of the modelled network
    pandapower.create_bus(net=DS_model, vn_kv=22, name='Slack_node_1', type='b', max_vm_pu=1.1, min_vm_pu=0, index=101)
    pandapower.create_bus(net=DS_model, vn_kv=22, name='Slack_node_2', type='b', max_vm_pu=1.1, min_vm_pu=0, index=102)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_1', type='b', max_vm_pu=1.1, min_vm_pu=0, index=1)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_2', type='b', max_vm_pu=1.1, min_vm_pu=0, index=2)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_3', type='b', max_vm_pu=1.1, min_vm_pu=0, index=3)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_4', type='b', max_vm_pu=1.1, min_vm_pu=0, index=4)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_5', type='b', max_vm_pu=1.1, min_vm_pu=0, index=5)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_6', type='b', max_vm_pu=1.1, min_vm_pu=0, index=6)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_7', type='b', max_vm_pu=1.1, min_vm_pu=0, index=7)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_8', type='b', max_vm_pu=1.1, min_vm_pu=0, index=8)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_9', type='b', max_vm_pu=1.1, min_vm_pu=0, index=9)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_10', type='b', max_vm_pu=1.1, min_vm_pu=0, index=10)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_11', type='b', max_vm_pu=1.1, min_vm_pu=0, index=11)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_12', type='b', max_vm_pu=1.1, min_vm_pu=0, index=12)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_13', type='b', max_vm_pu=1.1, min_vm_pu=0, index=13)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_14', type='b', max_vm_pu=1.1, min_vm_pu=0, index=14)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_15', type='b', max_vm_pu=1.1, min_vm_pu=0, index=15)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_16', type='b', max_vm_pu=1.1, min_vm_pu=0, index=16)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_17', type='b', max_vm_pu=1.1, min_vm_pu=0, index=17)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_18', type='b', max_vm_pu=1.1, min_vm_pu=0, index=18)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_19', type='b', max_vm_pu=1.1, min_vm_pu=0, index=19)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_20', type='b', max_vm_pu=1.1, min_vm_pu=0, index=20)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_21', type='b', max_vm_pu=1.1, min_vm_pu=0, index=21)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_22', type='b', max_vm_pu=1.1, min_vm_pu=0, index=22)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_23', type='b', max_vm_pu=1.1, min_vm_pu=0, index=23)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_24', type='b', max_vm_pu=1.1, min_vm_pu=0, index=24)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_25', type='b', max_vm_pu=1.1, min_vm_pu=0, index=25)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_26', type='b', max_vm_pu=1.1, min_vm_pu=0, index=26)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_27', type='b', max_vm_pu=1.1, min_vm_pu=0, index=27)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_28', type='b', max_vm_pu=1.1, min_vm_pu=0, index=28)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_29', type='b', max_vm_pu=1.1, min_vm_pu=0, index=29)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_30', type='b', max_vm_pu=1.1, min_vm_pu=0, index=30)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_31', type='b', max_vm_pu=1.1, min_vm_pu=0, index=31)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_32', type='b', max_vm_pu=1.1, min_vm_pu=0, index=32)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_33', type='b', max_vm_pu=1.1, min_vm_pu=0, index=33)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_34', type='b', max_vm_pu=1.1, min_vm_pu=0, index=34)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_35', type='b', max_vm_pu=1.1, min_vm_pu=0, index=35)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_36', type='b', max_vm_pu=1.1, min_vm_pu=0, index=36)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_37', type='b', max_vm_pu=1.1, min_vm_pu=0, index=37)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_38', type='b', max_vm_pu=1.1, min_vm_pu=0, index=38)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_39', type='b', max_vm_pu=1.1, min_vm_pu=0, index=39)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_40', type='b', max_vm_pu=1.1, min_vm_pu=0, index=40)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_41', type='b', max_vm_pu=1.1, min_vm_pu=0, index=41)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_42', type='b', max_vm_pu=1.1, min_vm_pu=0, index=42)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_43', type='b', max_vm_pu=1.1, min_vm_pu=0, index=43)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_44', type='b', max_vm_pu=1.1, min_vm_pu=0, index=44)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_45', type='b', max_vm_pu=1.1, min_vm_pu=0, index=45)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_46', type='b', max_vm_pu=1.1, min_vm_pu=0, index=46)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_47', type='b', max_vm_pu=1.1, min_vm_pu=0, index=47)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_48', type='b', max_vm_pu=1.1, min_vm_pu=0, index=48)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_49', type='b', max_vm_pu=1.1, min_vm_pu=0, index=49)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_50', type='b', max_vm_pu=1.1, min_vm_pu=0, index=50)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_51', type='b', max_vm_pu=1.1, min_vm_pu=0, index=51)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_52', type='b', max_vm_pu=1.1, min_vm_pu=0, index=52)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_53', type='b', max_vm_pu=1.1, min_vm_pu=0, index=53)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_54', type='b', max_vm_pu=1.1, min_vm_pu=0, index=54)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_55', type='b', max_vm_pu=1.1, min_vm_pu=0, index=55)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_56', type='b', max_vm_pu=1.1, min_vm_pu=0, index=56)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_57', type='b', max_vm_pu=1.1, min_vm_pu=0, index=57)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_58', type='b', max_vm_pu=1.1, min_vm_pu=0, index=58)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_59', type='b', max_vm_pu=1.1, min_vm_pu=0, index=59)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_60', type='b', max_vm_pu=1.1, min_vm_pu=0, index=60)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_61', type='b', max_vm_pu=1.1, min_vm_pu=0, index=61)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_62', type='b', max_vm_pu=1.1, min_vm_pu=0, index=62)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_63', type='b', max_vm_pu=1.1, min_vm_pu=0, index=63)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_64', type='b', max_vm_pu=1.1, min_vm_pu=0, index=64)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_65', type='b', max_vm_pu=1.1, min_vm_pu=0, index=65)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_66', type='b', max_vm_pu=1.1, min_vm_pu=0, index=66)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_67', type='b', max_vm_pu=1.1, min_vm_pu=0, index=67)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_68', type='b', max_vm_pu=1.1, min_vm_pu=0, index=68)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_69', type='b', max_vm_pu=1.1, min_vm_pu=0, index=69)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_70', type='b', max_vm_pu=1.1, min_vm_pu=0, index=70)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_71', type='b', max_vm_pu=1.1, min_vm_pu=0, index=71)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_72', type='b', max_vm_pu=1.1, min_vm_pu=0, index=72)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_73', type='b', max_vm_pu=1.1, min_vm_pu=0, index=73)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_74', type='b', max_vm_pu=1.1, min_vm_pu=0, index=74)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_75', type='b', max_vm_pu=1.1, min_vm_pu=0, index=75)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_76', type='b', max_vm_pu=1.1, min_vm_pu=0, index=76)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_77', type='b', max_vm_pu=1.1, min_vm_pu=0, index=77)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_78', type='b', max_vm_pu=1.1, min_vm_pu=0, index=78)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_79', type='b', max_vm_pu=1.1, min_vm_pu=0, index=79)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_80', type='b', max_vm_pu=1.1, min_vm_pu=0, index=80)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_81', type='b', max_vm_pu=1.1, min_vm_pu=0, index=81)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_82', type='b', max_vm_pu=1.1, min_vm_pu=0, index=82)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_83', type='b', max_vm_pu=1.1, min_vm_pu=0, index=83)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_84', type='b', max_vm_pu=1.1, min_vm_pu=0, index=84)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_85', type='b', max_vm_pu=1.1, min_vm_pu=0, index=85)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_86', type='b', max_vm_pu=1.1, min_vm_pu=0, index=86)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_87', type='b', max_vm_pu=1.1, min_vm_pu=0, index=87)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_88', type='b', max_vm_pu=1.1, min_vm_pu=0, index=88)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_89', type='b', max_vm_pu=1.1, min_vm_pu=0, index=89)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_90', type='b', max_vm_pu=1.1, min_vm_pu=0, index=90)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_91', type='b', max_vm_pu=1.1, min_vm_pu=0, index=91)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_92', type='b', max_vm_pu=1.1, min_vm_pu=0, index=92)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_93', type='b', max_vm_pu=1.1, min_vm_pu=0, index=93)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_94', type='b', max_vm_pu=1.1, min_vm_pu=0, index=94)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_95', type='b', max_vm_pu=1.1, min_vm_pu=0, index=95)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_96', type='b', max_vm_pu=1.1, min_vm_pu=0, index=96)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_97', type='b', max_vm_pu=1.1, min_vm_pu=0, index=97)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_98', type='b', max_vm_pu=1.1, min_vm_pu=0, index=98)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_99', type='b', max_vm_pu=1.1, min_vm_pu=0, index=99)
    pandapower.create_bus(net=DS_model, vn_kv=0.4, name='PQ_node_100', type='b', max_vm_pu=1.1, min_vm_pu=0, index=100)

    # Create individual power-line sections of the modelled network
    pandapower.create_line(net=DS_model, from_bus=1, to_bus=2, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_1_2', index=1000001, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=2, to_bus=3, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_2_3', index=1000002, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=3, to_bus=4, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_3_4', index=1000003, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=4, to_bus=5, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_4_5', index=1000004, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=5, to_bus=6, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_5_6', index=1000005, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=6, to_bus=7, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_6_7', index=1000006, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=7, to_bus=8, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_7_8', index=1000007, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=8, to_bus=9, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_8_9', index=1000008, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=9, to_bus=10, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_9_10', index=1000009, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=11, to_bus=12, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_11_12', index=1000010, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=12, to_bus=13, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_12_13', index=1000011, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=13, to_bus=14, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_13_14', index=1000012, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=14, to_bus=15, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_14_15', index=1000013, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=15, to_bus=16, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_15_16', index=1000014, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=16, to_bus=17, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_16_17', index=1000015, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=17, to_bus=18, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_17_18', index=1000016, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=18, to_bus=19, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_18_19', index=1000017, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=19, to_bus=20, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_19_20', index=1000018, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=21, to_bus=22, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_21_22', index=1000019, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=22, to_bus=23, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_22_23', index=1000020, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=23, to_bus=24, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_23_24', index=1000021, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=24, to_bus=25, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_24_25', index=1000022, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=25, to_bus=26, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_25_26', index=1000023, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=26, to_bus=27, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_26_27', index=1000024, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=27, to_bus=28, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_27_28', index=1000025, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=28, to_bus=29, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_28_29', index=1000026, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=29, to_bus=30, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_29_30', index=1000027, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=31, to_bus=32, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_31_32', index=1000028, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=32, to_bus=33, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_32_33', index=1000029, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=33, to_bus=34, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_33_34', index=1000030, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=34, to_bus=35, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_34_35', index=1000031, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=35, to_bus=36, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_35_36', index=1000032, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=36, to_bus=37, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_36_37', index=1000033, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=37, to_bus=38, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_37_38', index=1000034, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=38, to_bus=39, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_38_39', index=1000035, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=39, to_bus=40, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_39_40', index=1000036, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=41, to_bus=42, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_41_42', index=1000037, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=42, to_bus=43, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_42_43', index=1000038, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=43, to_bus=44, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_43_44', index=1000039, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=44, to_bus=45, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_44_45', index=1000040, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=45, to_bus=46, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_45_46', index=1000041, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=46, to_bus=47, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_46_47', index=1000042, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=47, to_bus=48, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_47_48', index=1000043, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=48, to_bus=49, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_48_49', index=1000044, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=49, to_bus=50, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_49_50', index=1000045, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=51, to_bus=52, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_51_52', index=1000046, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=52, to_bus=53, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_52_53', index=1000047, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=53, to_bus=54, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_53_54', index=1000048, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=54, to_bus=55, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_54_55', index=1000049, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=55, to_bus=56, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_55_56', index=1000050, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=56, to_bus=57, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_56_57', index=1000051, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=57, to_bus=58, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_57_58', index=1000052, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=58, to_bus=59, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_58_59', index=1000053, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=59, to_bus=60, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_59_60', index=1000054, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=61, to_bus=62, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_61_62', index=1000055, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=62, to_bus=63, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_62_63', index=1000056, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=63, to_bus=64, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_63_64', index=1000057, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=64, to_bus=65, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_64_65', index=1000058, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=65, to_bus=66, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_65_66', index=1000059, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=66, to_bus=67, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_66_67', index=1000060, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=67, to_bus=68, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_67_68', index=1000061, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=68, to_bus=69, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_68_69', index=1000062, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=69, to_bus=70, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_69_70', index=1000063, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=71, to_bus=72, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_71_72', index=1000064, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=72, to_bus=73, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_72_73', index=1000065, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=73, to_bus=74, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_73_74', index=1000066, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=74, to_bus=75, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_74_75', index=1000067, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=75, to_bus=76, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_75_76', index=1000068, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=76, to_bus=77, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_76_77', index=1000069, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=77, to_bus=78, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_77_78', index=1000070, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=78, to_bus=79, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_78_79', index=1000071, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=79, to_bus=80, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_79_80', index=1000072, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=81, to_bus=82, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_81_82', index=1000073, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=82, to_bus=83, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_82_83', index=1000074, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=83, to_bus=84, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_83_84', index=1000075, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=84, to_bus=85, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_84_85', index=1000076, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=85, to_bus=86, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_85_86', index=1000077, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=86, to_bus=87, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_86_87', index=1000078, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=87, to_bus=88, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_87_88', index=1000079, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=88, to_bus=89, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_88_89', index=1000080, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=89, to_bus=90, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_89_90', index=1000081, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=91, to_bus=92, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_91_92', index=1000082, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=92, to_bus=93, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_92_93', index=1000083, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=93, to_bus=94, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_93_94', index=1000084, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=94, to_bus=95, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_94_95', index=1000085, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=95, to_bus=96, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_95_96', index=1000086, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=96, to_bus=97, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_96_97', index=1000087, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=97, to_bus=98, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_97_98', index=1000088, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=98, to_bus=99, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_98_99', index=1000089, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=99, to_bus=100, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_99_100', index=1000090, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=1, to_bus=11, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_1_11', index=1000091, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=2, to_bus=12, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_2_12', index=1000092, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=3, to_bus=13, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_3_13', index=1000093, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=4, to_bus=14, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_4_14', index=1000094, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=5, to_bus=15, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_5_15', index=1000095, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=6, to_bus=16, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_6_16', index=1000096, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=7, to_bus=17, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_7_17', index=1000097, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=8, to_bus=18, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_8_18', index=1000098, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=9, to_bus=19, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_9_19', index=1000099, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=10, to_bus=20, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_10_20', index=1000100, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=11, to_bus=21, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_11_21', index=1000101, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=12, to_bus=22, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_12_22', index=1000102, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=13, to_bus=23, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_13_23', index=1000103, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=14, to_bus=24, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_14_24', index=1000104, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=15, to_bus=25, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_15_25', index=1000105, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=16, to_bus=26, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_16_26', index=1000106, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=17, to_bus=27, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_17_27', index=1000107, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=18, to_bus=28, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_18_28', index=1000108, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=19, to_bus=29, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_19_29', index=1000109, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=20, to_bus=30, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_20_30', index=1000110, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=21, to_bus=31, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_21_31', index=1000111, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=22, to_bus=32, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_22_32', index=1000112, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=23, to_bus=33, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_23_33', index=1000113, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=24, to_bus=34, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_24_34', index=1000114, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=25, to_bus=35, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_25_35', index=1000115, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=26, to_bus=36, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_26_36', index=1000116, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=27, to_bus=37, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_27_37', index=1000117, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=28, to_bus=38, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_28_38', index=1000118, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=29, to_bus=39, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_29_39', index=1000119, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=30, to_bus=40, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_30_40', index=1000120, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=31, to_bus=41, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_31_41', index=1000121, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=32, to_bus=42, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_32_42', index=1000122, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=33, to_bus=43, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_33_43', index=1000123, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=34, to_bus=44, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_34_44', index=1000124, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=35, to_bus=45, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_35_45', index=1000125, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=36, to_bus=46, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_36_46', index=1000126, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=37, to_bus=47, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_37_47', index=1000127, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=38, to_bus=48, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_38_48', index=1000128, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=39, to_bus=49, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_39_49', index=1000129, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=40, to_bus=50, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_40_50', index=1000130, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=41, to_bus=51, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_41_51', index=1000131, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=42, to_bus=52, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_42_52', index=1000132, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=43, to_bus=53, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_43_53', index=1000133, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=44, to_bus=54, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_44_54', index=1000134, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=45, to_bus=55, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_45_55', index=1000135, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=46, to_bus=56, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_46_56', index=1000136, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=47, to_bus=57, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_47_57', index=1000137, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=48, to_bus=58, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_48_58', index=1000138, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=49, to_bus=59, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_49_59', index=1000139, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=50, to_bus=60, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_50_60', index=1000140, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=51, to_bus=61, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_51_61', index=1000141, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=52, to_bus=62, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_52_62', index=1000142, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=53, to_bus=63, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_53_63', index=1000143, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=54, to_bus=64, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_54_64', index=1000144, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=55, to_bus=65, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_55_65', index=1000145, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=56, to_bus=66, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_56_66', index=1000146, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=57, to_bus=67, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_57_67', index=1000147, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=58, to_bus=68, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_58_68', index=1000148, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=59, to_bus=69, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_59_69', index=1000149, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=60, to_bus=70, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_60_70', index=1000150, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=61, to_bus=71, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_61_71', index=1000151, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=62, to_bus=72, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_62_72', index=1000152, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=63, to_bus=73, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_63_73', index=1000153, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=64, to_bus=74, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_64_74', index=1000154, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=65, to_bus=75, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_65_75', index=1000155, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=66, to_bus=76, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_66_76', index=1000156, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=67, to_bus=77, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_67_77', index=1000157, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=68, to_bus=78, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_68_78', index=1000158, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=69, to_bus=79, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_69_79', index=1000159, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=70, to_bus=80, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_70_80', index=1000160, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=71, to_bus=81, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_71_81', index=1000161, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=72, to_bus=82, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_72_82', index=1000162, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=73, to_bus=83, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_73_83', index=1000163, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=74, to_bus=84, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_74_84', index=1000164, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=75, to_bus=85, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_75_85', index=1000165, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=76, to_bus=86, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_76_86', index=1000166, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=77, to_bus=87, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_77_87', index=1000167, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=78, to_bus=88, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_78_88', index=1000168, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=79, to_bus=89, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_79_89', index=1000169, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=80, to_bus=90, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_80_90', index=1000170, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=81, to_bus=91, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_81_91', index=1000171, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=82, to_bus=92, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_82_92', index=1000172, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=83, to_bus=93, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_83_93', index=1000173, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=84, to_bus=94, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_84_94', index=1000174, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=85, to_bus=95, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_85_95', index=1000175, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=86, to_bus=96, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_86_96', index=1000176, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=87, to_bus=97, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_87_97', index=1000177, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=88, to_bus=98, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_88_98', index=1000178, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=89, to_bus=99, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_89_99', index=1000179, max_loading_percent=100)
    pandapower.create_line(net=DS_model, from_bus=90, to_bus=100, length_km=0.1, std_type='LVC_CYKY_4x50', name='PL_90_100', index=1000180, max_loading_percent=100)

    # Create power-line section switches (sectionalizers) – for any power-line section there will be created two switches: the first switch will be placed at the start point and the second one at the end point of the power-line section of the modelled network
    pandapower.create_switch(net=DS_model, bus=1, element=1000001, et='l', closed=True, type='CB', name='SW_1a', index=2000001, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=2, element=1000001, et='l', closed=True, type='CB', name='SW_1b', index=3000001, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=2, element=1000002, et='l', closed=True, type='CB', name='SW_2a', index=2000002, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=3, element=1000002, et='l', closed=True, type='CB', name='SW_2b', index=3000002, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=3, element=1000003, et='l', closed=True, type='CB', name='SW_3a', index=2000003, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=4, element=1000003, et='l', closed=True, type='CB', name='SW_3b', index=3000003, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=4, element=1000004, et='l', closed=True, type='CB', name='SW_4a', index=2000004, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=5, element=1000004, et='l', closed=True, type='CB', name='SW_4b', index=3000004, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=5, element=1000005, et='l', closed=True, type='CB', name='SW_5a', index=2000005, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=6, element=1000005, et='l', closed=True, type='CB', name='SW_5b', index=3000005, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=6, element=1000006, et='l', closed=True, type='CB', name='SW_6a', index=2000006, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=7, element=1000006, et='l', closed=True, type='CB', name='SW_6b', index=3000006, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=7, element=1000007, et='l', closed=True, type='CB', name='SW_7a', index=2000007, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=8, element=1000007, et='l', closed=True, type='CB', name='SW_7b', index=3000007, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=8, element=1000008, et='l', closed=True, type='CB', name='SW_8a', index=2000008, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=9, element=1000008, et='l', closed=True, type='CB', name='SW_8b', index=3000008, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=9, element=1000009, et='l', closed=True, type='CB', name='SW_9a', index=2000009, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=10, element=1000009, et='l', closed=True, type='CB', name='SW_9b', index=3000009, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=11, element=1000010, et='l', closed=True, type='CB', name='SW_10a', index=2000010, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=12, element=1000010, et='l', closed=True, type='CB', name='SW_10b', index=3000010, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=12, element=1000011, et='l', closed=True, type='CB', name='SW_11a', index=2000011, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=13, element=1000011, et='l', closed=True, type='CB', name='SW_11b', index=3000011, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=13, element=1000012, et='l', closed=True, type='CB', name='SW_12a', index=2000012, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=14, element=1000012, et='l', closed=True, type='CB', name='SW_12b', index=3000012, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=14, element=1000013, et='l', closed=True, type='CB', name='SW_13a', index=2000013, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=15, element=1000013, et='l', closed=True, type='CB', name='SW_13b', index=3000013, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=15, element=1000014, et='l', closed=True, type='CB', name='SW_14a', index=2000014, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=16, element=1000014, et='l', closed=True, type='CB', name='SW_14b', index=3000014, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=16, element=1000015, et='l', closed=True, type='CB', name='SW_15a', index=2000015, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=17, element=1000015, et='l', closed=True, type='CB', name='SW_15b', index=3000015, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=17, element=1000016, et='l', closed=True, type='CB', name='SW_16a', index=2000016, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=18, element=1000016, et='l', closed=True, type='CB', name='SW_16b', index=3000016, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=18, element=1000017, et='l', closed=True, type='CB', name='SW_17a', index=2000017, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=19, element=1000017, et='l', closed=True, type='CB', name='SW_17b', index=3000017, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=19, element=1000018, et='l', closed=True, type='CB', name='SW_18a', index=2000018, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=20, element=1000018, et='l', closed=True, type='CB', name='SW_18b', index=3000018, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=21, element=1000019, et='l', closed=True, type='CB', name='SW_19a', index=2000019, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=22, element=1000019, et='l', closed=True, type='CB', name='SW_19b', index=3000019, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=22, element=1000020, et='l', closed=True, type='CB', name='SW_20a', index=2000020, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=23, element=1000020, et='l', closed=True, type='CB', name='SW_20b', index=3000020, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=23, element=1000021, et='l', closed=True, type='CB', name='SW_21a', index=2000021, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=24, element=1000021, et='l', closed=True, type='CB', name='SW_21b', index=3000021, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=24, element=1000022, et='l', closed=True, type='CB', name='SW_22a', index=2000022, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=25, element=1000022, et='l', closed=True, type='CB', name='SW_22b', index=3000022, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=25, element=1000023, et='l', closed=True, type='CB', name='SW_23a', index=2000023, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=26, element=1000023, et='l', closed=True, type='CB', name='SW_23b', index=3000023, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=26, element=1000024, et='l', closed=True, type='CB', name='SW_24a', index=2000024, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=27, element=1000024, et='l', closed=True, type='CB', name='SW_24b', index=3000024, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=27, element=1000025, et='l', closed=True, type='CB', name='SW_25a', index=2000025, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=28, element=1000025, et='l', closed=True, type='CB', name='SW_25b', index=3000025, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=28, element=1000026, et='l', closed=True, type='CB', name='SW_26a', index=2000026, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=29, element=1000026, et='l', closed=True, type='CB', name='SW_26b', index=3000026, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=29, element=1000027, et='l', closed=True, type='CB', name='SW_27a', index=2000027, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=30, element=1000027, et='l', closed=True, type='CB', name='SW_27b', index=3000027, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=31, element=1000028, et='l', closed=True, type='CB', name='SW_28a', index=2000028, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=32, element=1000028, et='l', closed=True, type='CB', name='SW_28b', index=3000028, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=32, element=1000029, et='l', closed=True, type='CB', name='SW_29a', index=2000029, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=33, element=1000029, et='l', closed=True, type='CB', name='SW_29b', index=3000029, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=33, element=1000030, et='l', closed=True, type='CB', name='SW_30a', index=2000030, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=34, element=1000030, et='l', closed=True, type='CB', name='SW_30b', index=3000030, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=34, element=1000031, et='l', closed=True, type='CB', name='SW_31a', index=2000031, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=35, element=1000031, et='l', closed=True, type='CB', name='SW_31b', index=3000031, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=35, element=1000032, et='l', closed=True, type='CB', name='SW_32a', index=2000032, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=36, element=1000032, et='l', closed=True, type='CB', name='SW_32b', index=3000032, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=36, element=1000033, et='l', closed=True, type='CB', name='SW_33a', index=2000033, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=37, element=1000033, et='l', closed=True, type='CB', name='SW_33b', index=3000033, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=37, element=1000034, et='l', closed=True, type='CB', name='SW_34a', index=2000034, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=38, element=1000034, et='l', closed=True, type='CB', name='SW_34b', index=3000034, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=38, element=1000035, et='l', closed=True, type='CB', name='SW_35a', index=2000035, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=39, element=1000035, et='l', closed=True, type='CB', name='SW_35b', index=3000035, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=39, element=1000036, et='l', closed=True, type='CB', name='SW_36a', index=2000036, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=40, element=1000036, et='l', closed=True, type='CB', name='SW_36b', index=3000036, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=41, element=1000037, et='l', closed=True, type='CB', name='SW_37a', index=2000037, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=42, element=1000037, et='l', closed=True, type='CB', name='SW_37b', index=3000037, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=42, element=1000038, et='l', closed=True, type='CB', name='SW_38a', index=2000038, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=43, element=1000038, et='l', closed=True, type='CB', name='SW_38b', index=3000038, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=43, element=1000039, et='l', closed=True, type='CB', name='SW_39a', index=2000039, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=44, element=1000039, et='l', closed=True, type='CB', name='SW_39b', index=3000039, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=44, element=1000040, et='l', closed=True, type='CB', name='SW_40a', index=2000040, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=45, element=1000040, et='l', closed=True, type='CB', name='SW_40b', index=3000040, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=45, element=1000041, et='l', closed=True, type='CB', name='SW_41a', index=2000041, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=46, element=1000041, et='l', closed=True, type='CB', name='SW_41b', index=3000041, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=46, element=1000042, et='l', closed=True, type='CB', name='SW_42a', index=2000042, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=47, element=1000042, et='l', closed=True, type='CB', name='SW_42b', index=3000042, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=47, element=1000043, et='l', closed=True, type='CB', name='SW_43a', index=2000043, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=48, element=1000043, et='l', closed=True, type='CB', name='SW_43b', index=3000043, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=48, element=1000044, et='l', closed=True, type='CB', name='SW_44a', index=2000044, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=49, element=1000044, et='l', closed=True, type='CB', name='SW_44b', index=3000044, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=49, element=1000045, et='l', closed=True, type='CB', name='SW_45a', index=2000045, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=50, element=1000045, et='l', closed=True, type='CB', name='SW_45b', index=3000045, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=51, element=1000046, et='l', closed=True, type='CB', name='SW_46a', index=2000046, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=52, element=1000046, et='l', closed=True, type='CB', name='SW_46b', index=3000046, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=52, element=1000047, et='l', closed=True, type='CB', name='SW_47a', index=2000047, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=53, element=1000047, et='l', closed=True, type='CB', name='SW_47b', index=3000047, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=53, element=1000048, et='l', closed=True, type='CB', name='SW_48a', index=2000048, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=54, element=1000048, et='l', closed=True, type='CB', name='SW_48b', index=3000048, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=54, element=1000049, et='l', closed=True, type='CB', name='SW_49a', index=2000049, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=55, element=1000049, et='l', closed=True, type='CB', name='SW_49b', index=3000049, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=55, element=1000050, et='l', closed=True, type='CB', name='SW_50a', index=2000050, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=56, element=1000050, et='l', closed=True, type='CB', name='SW_50b', index=3000050, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=56, element=1000051, et='l', closed=True, type='CB', name='SW_51a', index=2000051, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=57, element=1000051, et='l', closed=True, type='CB', name='SW_51b', index=3000051, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=57, element=1000052, et='l', closed=True, type='CB', name='SW_52a', index=2000052, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=58, element=1000052, et='l', closed=True, type='CB', name='SW_52b', index=3000052, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=58, element=1000053, et='l', closed=True, type='CB', name='SW_53a', index=2000053, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=59, element=1000053, et='l', closed=True, type='CB', name='SW_53b', index=3000053, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=59, element=1000054, et='l', closed=True, type='CB', name='SW_54a', index=2000054, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=60, element=1000054, et='l', closed=True, type='CB', name='SW_54b', index=3000054, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=61, element=1000055, et='l', closed=True, type='CB', name='SW_55a', index=2000055, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=62, element=1000055, et='l', closed=True, type='CB', name='SW_55b', index=3000055, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=62, element=1000056, et='l', closed=True, type='CB', name='SW_56a', index=2000056, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=63, element=1000056, et='l', closed=True, type='CB', name='SW_56b', index=3000056, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=63, element=1000057, et='l', closed=True, type='CB', name='SW_57a', index=2000057, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=64, element=1000057, et='l', closed=True, type='CB', name='SW_57b', index=3000057, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=64, element=1000058, et='l', closed=True, type='CB', name='SW_58a', index=2000058, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=65, element=1000058, et='l', closed=True, type='CB', name='SW_58b', index=3000058, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=65, element=1000059, et='l', closed=True, type='CB', name='SW_59a', index=2000059, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=66, element=1000059, et='l', closed=True, type='CB', name='SW_59b', index=3000059, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=66, element=1000060, et='l', closed=True, type='CB', name='SW_60a', index=2000060, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=67, element=1000060, et='l', closed=True, type='CB', name='SW_60b', index=3000060, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=67, element=1000061, et='l', closed=True, type='CB', name='SW_61a', index=2000061, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=68, element=1000061, et='l', closed=True, type='CB', name='SW_61b', index=3000061, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=68, element=1000062, et='l', closed=True, type='CB', name='SW_62a', index=2000062, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=69, element=1000062, et='l', closed=True, type='CB', name='SW_62b', index=3000062, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=69, element=1000063, et='l', closed=True, type='CB', name='SW_63a', index=2000063, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=70, element=1000063, et='l', closed=True, type='CB', name='SW_63b', index=3000063, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=71, element=1000064, et='l', closed=True, type='CB', name='SW_64a', index=2000064, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=72, element=1000064, et='l', closed=True, type='CB', name='SW_64b', index=3000064, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=72, element=1000065, et='l', closed=True, type='CB', name='SW_65a', index=2000065, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=73, element=1000065, et='l', closed=True, type='CB', name='SW_65b', index=3000065, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=73, element=1000066, et='l', closed=True, type='CB', name='SW_66a', index=2000066, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=74, element=1000066, et='l', closed=True, type='CB', name='SW_66b', index=3000066, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=74, element=1000067, et='l', closed=True, type='CB', name='SW_67a', index=2000067, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=75, element=1000067, et='l', closed=True, type='CB', name='SW_67b', index=3000067, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=75, element=1000068, et='l', closed=True, type='CB', name='SW_68a', index=2000068, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=76, element=1000068, et='l', closed=True, type='CB', name='SW_68b', index=3000068, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=76, element=1000069, et='l', closed=True, type='CB', name='SW_69a', index=2000069, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=77, element=1000069, et='l', closed=True, type='CB', name='SW_69b', index=3000069, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=77, element=1000070, et='l', closed=True, type='CB', name='SW_70a', index=2000070, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=78, element=1000070, et='l', closed=True, type='CB', name='SW_70b', index=3000070, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=78, element=1000071, et='l', closed=True, type='CB', name='SW_71a', index=2000071, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=79, element=1000071, et='l', closed=True, type='CB', name='SW_71b', index=3000071, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=79, element=1000072, et='l', closed=True, type='CB', name='SW_72a', index=2000072, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=80, element=1000072, et='l', closed=True, type='CB', name='SW_72b', index=3000072, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=81, element=1000073, et='l', closed=True, type='CB', name='SW_73a', index=2000073, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=82, element=1000073, et='l', closed=True, type='CB', name='SW_73b', index=3000073, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=82, element=1000074, et='l', closed=True, type='CB', name='SW_74a', index=2000074, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=83, element=1000074, et='l', closed=True, type='CB', name='SW_74b', index=3000074, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=83, element=1000075, et='l', closed=True, type='CB', name='SW_75a', index=2000075, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=84, element=1000075, et='l', closed=True, type='CB', name='SW_75b', index=3000075, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=84, element=1000076, et='l', closed=True, type='CB', name='SW_76a', index=2000076, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=85, element=1000076, et='l', closed=True, type='CB', name='SW_76b', index=3000076, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=85, element=1000077, et='l', closed=True, type='CB', name='SW_77a', index=2000077, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=86, element=1000077, et='l', closed=True, type='CB', name='SW_77b', index=3000077, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=86, element=1000078, et='l', closed=True, type='CB', name='SW_78a', index=2000078, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=87, element=1000078, et='l', closed=True, type='CB', name='SW_78b', index=3000078, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=87, element=1000079, et='l', closed=True, type='CB', name='SW_79a', index=2000079, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=88, element=1000079, et='l', closed=True, type='CB', name='SW_79b', index=3000079, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=88, element=1000080, et='l', closed=True, type='CB', name='SW_80a', index=2000080, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=89, element=1000080, et='l', closed=True, type='CB', name='SW_80b', index=3000080, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=89, element=1000081, et='l', closed=True, type='CB', name='SW_81a', index=2000081, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=90, element=1000081, et='l', closed=True, type='CB', name='SW_81b', index=3000081, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=91, element=1000082, et='l', closed=True, type='CB', name='SW_82a', index=2000082, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=92, element=1000082, et='l', closed=True, type='CB', name='SW_82b', index=3000082, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=92, element=1000083, et='l', closed=True, type='CB', name='SW_83a', index=2000083, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=93, element=1000083, et='l', closed=True, type='CB', name='SW_83b', index=3000083, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=93, element=1000084, et='l', closed=True, type='CB', name='SW_84a', index=2000084, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=94, element=1000084, et='l', closed=True, type='CB', name='SW_84b', index=3000084, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=94, element=1000085, et='l', closed=True, type='CB', name='SW_85a', index=2000085, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=95, element=1000085, et='l', closed=True, type='CB', name='SW_85b', index=3000085, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=95, element=1000086, et='l', closed=True, type='CB', name='SW_86a', index=2000086, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=96, element=1000086, et='l', closed=True, type='CB', name='SW_86b', index=3000086, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=96, element=1000087, et='l', closed=True, type='CB', name='SW_87a', index=2000087, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=97, element=1000087, et='l', closed=True, type='CB', name='SW_87b', index=3000087, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=97, element=1000088, et='l', closed=True, type='CB', name='SW_88a', index=2000088, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=98, element=1000088, et='l', closed=True, type='CB', name='SW_88b', index=3000088, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=98, element=1000089, et='l', closed=True, type='CB', name='SW_89a', index=2000089, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=99, element=1000089, et='l', closed=True, type='CB', name='SW_89b', index=3000089, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=99, element=1000090, et='l', closed=True, type='CB', name='SW_90a', index=2000090, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=100, element=1000090, et='l', closed=True, type='CB', name='SW_90b', index=3000090, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=1, element=1000091, et='l', closed=True, type='CB', name='SW_91a', index=2000091, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=11, element=1000091, et='l', closed=True, type='CB', name='SW_91b', index=3000091, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=2, element=1000092, et='l', closed=True, type='CB', name='SW_92a', index=2000092, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=12, element=1000092, et='l', closed=True, type='CB', name='SW_92b', index=3000092, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=3, element=1000093, et='l', closed=True, type='CB', name='SW_93a', index=2000093, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=13, element=1000093, et='l', closed=True, type='CB', name='SW_93b', index=3000093, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=4, element=1000094, et='l', closed=True, type='CB', name='SW_94a', index=2000094, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=14, element=1000094, et='l', closed=True, type='CB', name='SW_94b', index=3000094, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=5, element=1000095, et='l', closed=True, type='CB', name='SW_95a', index=2000095, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=15, element=1000095, et='l', closed=True, type='CB', name='SW_95b', index=3000095, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=6, element=1000096, et='l', closed=True, type='CB', name='SW_96a', index=2000096, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=16, element=1000096, et='l', closed=True, type='CB', name='SW_96b', index=3000096, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=7, element=1000097, et='l', closed=True, type='CB', name='SW_97a', index=2000097, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=17, element=1000097, et='l', closed=True, type='CB', name='SW_97b', index=3000097, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=8, element=1000098, et='l', closed=True, type='CB', name='SW_98a', index=2000098, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=18, element=1000098, et='l', closed=True, type='CB', name='SW_98b', index=3000098, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=9, element=1000099, et='l', closed=True, type='CB', name='SW_99a', index=2000099, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=19, element=1000099, et='l', closed=True, type='CB', name='SW_99b', index=3000099, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=10, element=1000100, et='l', closed=True, type='CB', name='SW_100a', index=2000100, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=20, element=1000100, et='l', closed=True, type='CB', name='SW_100b', index=3000100, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=11, element=1000101, et='l', closed=True, type='CB', name='SW_101a', index=2000101, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=21, element=1000101, et='l', closed=True, type='CB', name='SW_101b', index=3000101, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=12, element=1000102, et='l', closed=True, type='CB', name='SW_102a', index=2000102, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=22, element=1000102, et='l', closed=True, type='CB', name='SW_102b', index=3000102, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=13, element=1000103, et='l', closed=True, type='CB', name='SW_103a', index=2000103, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=23, element=1000103, et='l', closed=True, type='CB', name='SW_103b', index=3000103, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=14, element=1000104, et='l', closed=True, type='CB', name='SW_104a', index=2000104, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=24, element=1000104, et='l', closed=True, type='CB', name='SW_104b', index=3000104, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=15, element=1000105, et='l', closed=True, type='CB', name='SW_105a', index=2000105, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=25, element=1000105, et='l', closed=True, type='CB', name='SW_105b', index=3000105, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=16, element=1000106, et='l', closed=True, type='CB', name='SW_106a', index=2000106, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=26, element=1000106, et='l', closed=True, type='CB', name='SW_106b', index=3000106, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=17, element=1000107, et='l', closed=True, type='CB', name='SW_107a', index=2000107, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=27, element=1000107, et='l', closed=True, type='CB', name='SW_107b', index=3000107, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=18, element=1000108, et='l', closed=True, type='CB', name='SW_108a', index=2000108, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=28, element=1000108, et='l', closed=True, type='CB', name='SW_108b', index=3000108, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=19, element=1000109, et='l', closed=True, type='CB', name='SW_109a', index=2000109, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=29, element=1000109, et='l', closed=True, type='CB', name='SW_109b', index=3000109, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=20, element=1000110, et='l', closed=True, type='CB', name='SW_110a', index=2000110, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=30, element=1000110, et='l', closed=True, type='CB', name='SW_110b', index=3000110, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=21, element=1000111, et='l', closed=True, type='CB', name='SW_111a', index=2000111, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=31, element=1000111, et='l', closed=True, type='CB', name='SW_111b', index=3000111, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=22, element=1000112, et='l', closed=True, type='CB', name='SW_112a', index=2000112, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=32, element=1000112, et='l', closed=True, type='CB', name='SW_112b', index=3000112, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=23, element=1000113, et='l', closed=True, type='CB', name='SW_113a', index=2000113, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=33, element=1000113, et='l', closed=True, type='CB', name='SW_113b', index=3000113, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=24, element=1000114, et='l', closed=True, type='CB', name='SW_114a', index=2000114, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=34, element=1000114, et='l', closed=True, type='CB', name='SW_114b', index=3000114, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=25, element=1000115, et='l', closed=True, type='CB', name='SW_115a', index=2000115, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=35, element=1000115, et='l', closed=True, type='CB', name='SW_115b', index=3000115, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=26, element=1000116, et='l', closed=True, type='CB', name='SW_116a', index=2000116, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=36, element=1000116, et='l', closed=True, type='CB', name='SW_116b', index=3000116, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=27, element=1000117, et='l', closed=True, type='CB', name='SW_117a', index=2000117, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=37, element=1000117, et='l', closed=True, type='CB', name='SW_117b', index=3000117, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=28, element=1000118, et='l', closed=True, type='CB', name='SW_118a', index=2000118, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=38, element=1000118, et='l', closed=True, type='CB', name='SW_118b', index=3000118, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=29, element=1000119, et='l', closed=True, type='CB', name='SW_119a', index=2000119, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=39, element=1000119, et='l', closed=True, type='CB', name='SW_119b', index=3000119, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=30, element=1000120, et='l', closed=True, type='CB', name='SW_120a', index=2000120, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=40, element=1000120, et='l', closed=True, type='CB', name='SW_120b', index=3000120, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=31, element=1000121, et='l', closed=True, type='CB', name='SW_121a', index=2000121, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=41, element=1000121, et='l', closed=True, type='CB', name='SW_121b', index=3000121, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=32, element=1000122, et='l', closed=True, type='CB', name='SW_122a', index=2000122, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=42, element=1000122, et='l', closed=True, type='CB', name='SW_122b', index=3000122, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=33, element=1000123, et='l', closed=True, type='CB', name='SW_123a', index=2000123, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=43, element=1000123, et='l', closed=True, type='CB', name='SW_123b', index=3000123, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=34, element=1000124, et='l', closed=True, type='CB', name='SW_124a', index=2000124, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=44, element=1000124, et='l', closed=True, type='CB', name='SW_124b', index=3000124, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=35, element=1000125, et='l', closed=True, type='CB', name='SW_125a', index=2000125, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=45, element=1000125, et='l', closed=True, type='CB', name='SW_125b', index=3000125, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=36, element=1000126, et='l', closed=True, type='CB', name='SW_126a', index=2000126, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=46, element=1000126, et='l', closed=True, type='CB', name='SW_126b', index=3000126, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=37, element=1000127, et='l', closed=True, type='CB', name='SW_127a', index=2000127, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=47, element=1000127, et='l', closed=True, type='CB', name='SW_127b', index=3000127, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=38, element=1000128, et='l', closed=True, type='CB', name='SW_128a', index=2000128, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=48, element=1000128, et='l', closed=True, type='CB', name='SW_128b', index=3000128, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=39, element=1000129, et='l', closed=True, type='CB', name='SW_129a', index=2000129, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=49, element=1000129, et='l', closed=True, type='CB', name='SW_129b', index=3000129, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=40, element=1000130, et='l', closed=True, type='CB', name='SW_130a', index=2000130, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=50, element=1000130, et='l', closed=True, type='CB', name='SW_130b', index=3000130, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=41, element=1000131, et='l', closed=True, type='CB', name='SW_131a', index=2000131, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=51, element=1000131, et='l', closed=True, type='CB', name='SW_131b', index=3000131, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=42, element=1000132, et='l', closed=True, type='CB', name='SW_132a', index=2000132, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=52, element=1000132, et='l', closed=True, type='CB', name='SW_132b', index=3000132, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=43, element=1000133, et='l', closed=True, type='CB', name='SW_133a', index=2000133, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=53, element=1000133, et='l', closed=True, type='CB', name='SW_133b', index=3000133, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=44, element=1000134, et='l', closed=True, type='CB', name='SW_134a', index=2000134, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=54, element=1000134, et='l', closed=True, type='CB', name='SW_134b', index=3000134, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=45, element=1000135, et='l', closed=True, type='CB', name='SW_135a', index=2000135, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=55, element=1000135, et='l', closed=True, type='CB', name='SW_135b', index=3000135, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=46, element=1000136, et='l', closed=True, type='CB', name='SW_136a', index=2000136, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=56, element=1000136, et='l', closed=True, type='CB', name='SW_136b', index=3000136, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=47, element=1000137, et='l', closed=True, type='CB', name='SW_137a', index=2000137, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=57, element=1000137, et='l', closed=True, type='CB', name='SW_137b', index=3000137, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=48, element=1000138, et='l', closed=True, type='CB', name='SW_138a', index=2000138, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=58, element=1000138, et='l', closed=True, type='CB', name='SW_138b', index=3000138, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=49, element=1000139, et='l', closed=True, type='CB', name='SW_139a', index=2000139, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=59, element=1000139, et='l', closed=True, type='CB', name='SW_139b', index=3000139, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=50, element=1000140, et='l', closed=True, type='CB', name='SW_140a', index=2000140, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=60, element=1000140, et='l', closed=True, type='CB', name='SW_140b', index=3000140, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=51, element=1000141, et='l', closed=True, type='CB', name='SW_141a', index=2000141, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=61, element=1000141, et='l', closed=True, type='CB', name='SW_141b', index=3000141, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=52, element=1000142, et='l', closed=True, type='CB', name='SW_142a', index=2000142, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=62, element=1000142, et='l', closed=True, type='CB', name='SW_142b', index=3000142, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=53, element=1000143, et='l', closed=True, type='CB', name='SW_143a', index=2000143, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=63, element=1000143, et='l', closed=True, type='CB', name='SW_143b', index=3000143, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=54, element=1000144, et='l', closed=True, type='CB', name='SW_144a', index=2000144, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=64, element=1000144, et='l', closed=True, type='CB', name='SW_144b', index=3000144, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=55, element=1000145, et='l', closed=True, type='CB', name='SW_145a', index=2000145, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=65, element=1000145, et='l', closed=True, type='CB', name='SW_145b', index=3000145, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=56, element=1000146, et='l', closed=True, type='CB', name='SW_146a', index=2000146, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=66, element=1000146, et='l', closed=True, type='CB', name='SW_146b', index=3000146, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=57, element=1000147, et='l', closed=True, type='CB', name='SW_147a', index=2000147, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=67, element=1000147, et='l', closed=True, type='CB', name='SW_147b', index=3000147, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=58, element=1000148, et='l', closed=True, type='CB', name='SW_148a', index=2000148, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=68, element=1000148, et='l', closed=True, type='CB', name='SW_148b', index=3000148, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=59, element=1000149, et='l', closed=True, type='CB', name='SW_149a', index=2000149, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=69, element=1000149, et='l', closed=True, type='CB', name='SW_149b', index=3000149, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=60, element=1000150, et='l', closed=True, type='CB', name='SW_150a', index=2000150, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=70, element=1000150, et='l', closed=True, type='CB', name='SW_150b', index=3000150, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=61, element=1000151, et='l', closed=True, type='CB', name='SW_151a', index=2000151, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=71, element=1000151, et='l', closed=True, type='CB', name='SW_151b', index=3000151, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=62, element=1000152, et='l', closed=True, type='CB', name='SW_152a', index=2000152, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=72, element=1000152, et='l', closed=True, type='CB', name='SW_152b', index=3000152, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=63, element=1000153, et='l', closed=True, type='CB', name='SW_153a', index=2000153, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=73, element=1000153, et='l', closed=True, type='CB', name='SW_153b', index=3000153, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=64, element=1000154, et='l', closed=True, type='CB', name='SW_154a', index=2000154, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=74, element=1000154, et='l', closed=True, type='CB', name='SW_154b', index=3000154, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=65, element=1000155, et='l', closed=True, type='CB', name='SW_155a', index=2000155, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=75, element=1000155, et='l', closed=True, type='CB', name='SW_155b', index=3000155, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=66, element=1000156, et='l', closed=True, type='CB', name='SW_156a', index=2000156, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=76, element=1000156, et='l', closed=True, type='CB', name='SW_156b', index=3000156, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=67, element=1000157, et='l', closed=True, type='CB', name='SW_157a', index=2000157, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=77, element=1000157, et='l', closed=True, type='CB', name='SW_157b', index=3000157, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=68, element=1000158, et='l', closed=True, type='CB', name='SW_158a', index=2000158, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=78, element=1000158, et='l', closed=True, type='CB', name='SW_158b', index=3000158, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=69, element=1000159, et='l', closed=True, type='CB', name='SW_159a', index=2000159, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=79, element=1000159, et='l', closed=True, type='CB', name='SW_159b', index=3000159, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=70, element=1000160, et='l', closed=True, type='CB', name='SW_160a', index=2000160, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=80, element=1000160, et='l', closed=True, type='CB', name='SW_160b', index=3000160, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=71, element=1000161, et='l', closed=True, type='CB', name='SW_161a', index=2000161, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=81, element=1000161, et='l', closed=True, type='CB', name='SW_161b', index=3000161, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=72, element=1000162, et='l', closed=True, type='CB', name='SW_162a', index=2000162, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=82, element=1000162, et='l', closed=True, type='CB', name='SW_162b', index=3000162, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=73, element=1000163, et='l', closed=True, type='CB', name='SW_163a', index=2000163, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=83, element=1000163, et='l', closed=True, type='CB', name='SW_163b', index=3000163, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=74, element=1000164, et='l', closed=True, type='CB', name='SW_164a', index=2000164, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=84, element=1000164, et='l', closed=True, type='CB', name='SW_164b', index=3000164, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=75, element=1000165, et='l', closed=True, type='CB', name='SW_165a', index=2000165, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=85, element=1000165, et='l', closed=True, type='CB', name='SW_165b', index=3000165, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=76, element=1000166, et='l', closed=True, type='CB', name='SW_166a', index=2000166, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=86, element=1000166, et='l', closed=True, type='CB', name='SW_166b', index=3000166, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=77, element=1000167, et='l', closed=True, type='CB', name='SW_167a', index=2000167, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=87, element=1000167, et='l', closed=True, type='CB', name='SW_167b', index=3000167, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=78, element=1000168, et='l', closed=True, type='CB', name='SW_168a', index=2000168, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=88, element=1000168, et='l', closed=True, type='CB', name='SW_168b', index=3000168, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=79, element=1000169, et='l', closed=True, type='CB', name='SW_169a', index=2000169, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=89, element=1000169, et='l', closed=True, type='CB', name='SW_169b', index=3000169, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=80, element=1000170, et='l', closed=True, type='CB', name='SW_170a', index=2000170, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=90, element=1000170, et='l', closed=True, type='CB', name='SW_170b', index=3000170, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=81, element=1000171, et='l', closed=True, type='CB', name='SW_171a', index=2000171, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=91, element=1000171, et='l', closed=True, type='CB', name='SW_171b', index=3000171, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=82, element=1000172, et='l', closed=True, type='CB', name='SW_172a', index=2000172, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=92, element=1000172, et='l', closed=True, type='CB', name='SW_172b', index=3000172, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=83, element=1000173, et='l', closed=True, type='CB', name='SW_173a', index=2000173, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=93, element=1000173, et='l', closed=True, type='CB', name='SW_173b', index=3000173, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=84, element=1000174, et='l', closed=True, type='CB', name='SW_174a', index=2000174, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=94, element=1000174, et='l', closed=True, type='CB', name='SW_174b', index=3000174, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=85, element=1000175, et='l', closed=True, type='CB', name='SW_175a', index=2000175, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=95, element=1000175, et='l', closed=True, type='CB', name='SW_175b', index=3000175, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=86, element=1000176, et='l', closed=True, type='CB', name='SW_176a', index=2000176, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=96, element=1000176, et='l', closed=True, type='CB', name='SW_176b', index=3000176, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=87, element=1000177, et='l', closed=True, type='CB', name='SW_177a', index=2000177, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=97, element=1000177, et='l', closed=True, type='CB', name='SW_177b', index=3000177, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=88, element=1000178, et='l', closed=True, type='CB', name='SW_178a', index=2000178, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=98, element=1000178, et='l', closed=True, type='CB', name='SW_178b', index=3000178, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=89, element=1000179, et='l', closed=True, type='CB', name='SW_179a', index=2000179, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=99, element=1000179, et='l', closed=True, type='CB', name='SW_179b', index=3000179, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=90, element=1000180, et='l', closed=True, type='CB', name='SW_180a', index=2000180, z_ohm=0)
    pandapower.create_switch(net=DS_model, bus=100, element=1000180, et='l', closed=True, type='CB', name='SW_180b', index=3000180, z_ohm=0)

    # Create individual power consumers (all power consumers are set to consume a constant value of active and reactive power - it means that a value of active and reactive power taken from the network in the load connection node is independent of the local voltage magnitude)
    pandapower.create_load(net=DS_model, bus=2, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC2', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=3, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC3', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=4, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC4', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=5, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC5', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=6, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC6', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=7, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC7', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=8, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC8', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=9, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC9', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=10, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC10', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=11, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC11', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=12, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC12', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=13, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC13', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=14, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC14', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=15, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC15', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=16, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC16', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=17, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC17', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=18, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC18', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=19, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC19', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=20, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC20', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=21, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC21', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=22, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC22', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=23, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC23', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=24, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC24', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=25, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC25', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=26, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC26', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=27, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC27', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=28, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC28', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=29, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC29', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=30, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC30', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=31, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC31', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=32, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC32', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=33, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC33', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=34, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC34', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=35, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC35', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=36, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC36', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=37, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC37', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=38, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC38', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=39, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC39', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=40, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC40', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=41, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC41', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=42, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC42', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=43, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC43', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=44, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC44', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=45, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC45', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=46, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC46', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=47, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC47', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=48, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC48', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=49, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC49', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=50, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC50', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=51, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC51', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=52, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC52', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=53, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC53', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=54, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC54', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=55, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC55', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=56, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC56', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=57, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC57', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=58, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC58', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=59, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC59', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=60, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC60', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=61, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC61', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=62, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC62', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=63, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC63', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=64, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC64', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=65, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC65', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=66, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC66', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=67, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC67', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=68, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC68', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=69, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC69', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=70, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC70', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=71, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC71', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=72, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC72', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=73, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC73', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=74, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC74', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=75, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC75', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=76, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC76', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=77, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC77', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=78, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC78', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=79, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC79', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=80, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC80', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=81, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC81', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=82, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC82', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=83, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC83', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=84, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC84', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=85, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC85', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=86, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC86', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=87, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC87', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=88, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC88', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=89, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC89', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=90, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC90', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=91, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC91', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=92, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC92', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=93, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC93', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=94, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC94', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=95, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC95', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=96, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC96', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=97, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC97', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=98, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC98', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)
    pandapower.create_load(net=DS_model, bus=99, p_mw=0.006, q_mvar=0.001, const_z_percent=0, const_i_percent=0, name='PC99', max_p_mw=1, min_p_mw=0, max_q_mvar=1, min_q_mvar=0, controllable=True)

    # Create individual models of superior electrical networks … The local role of these superior networks is to provide a balance of active and reactive power here: if more active or reactive power is consumed than produced in the pandapower network model, then additional active or reactive power will flow into the pandapower network model from these superior networks; if more active or reactive power is produced than consumed in the pandapower network model, then excess active or reactive power will flow from the pandapower network model out through these superior networks
    pandapower.create_ext_grid(net=DS_model, bus=101, vm_pu=1, va_degree=0, name='Ext_MV_network_1', s_sc_max_mva=350, s_sc_min_mva=350, rx_max=0.8, rx_min=0, max_p_mw=100, min_p_mw=0, max_q_mvar=100, min_q_mvar=0)
    pandapower.create_ext_grid(net=DS_model, bus=102, vm_pu=1, va_degree=0, name='Ext_MV_network_2', s_sc_max_mva=350, s_sc_min_mva=350, rx_max=0.8, rx_min=0, max_p_mw=100, min_p_mw=0, max_q_mvar=100, min_q_mvar=0)

    # Create individual electrical transformers transmitting electrical power from the superior middle-voltage network to the local low-voltage network
    pandapower.create_transformer(net=DS_model, hv_bus=101, lv_bus=1, std_type='TR_type_1', name='TR1', max_loading_percent=100)
    pandapower.create_transformer(net=DS_model, hv_bus=102, lv_bus=100, std_type='TR_type_1', name='TR2', max_loading_percent=100)

    # Define the position of individual nodes of the pandapower network model
    DS_model.bus_geodata = read_json("""{"x":{"101":0,"102":11,"1":1,"2":2,"3":3,"4":4,"5":5,"6":6,"7":7,"8":8,"9":9,"10":10,"11":1,"12":2,"13":3,"14":4,"15":5,"16":6,"17":7,"18":8,"19":9,"20":10,"21":1,"22":2,"23":3,"24":4,"25":5,"26":6,"27":7,"28":8,"29":9,"30":10,"31":1,"32":2,"33":3,"34":4,"35":5,"36":6,"37":7,"38":8,"39":9,"40":10,"41":1,"42":2,"43":3,"44":4,"45":5,"46":6,"47":7,"48":8,"49":9,"50":10,"51":1,"52":2,"53":3,"54":4,"55":5,"56":6,"57":7,"58":8,"59":9,"60":10,"61":1,"62":2,"63":3,"64":4,"65":5,"66":6,"67":7,"68":8,"69":9,"70":10,"71":1,"72":2,"73":3,"74":4,"75":5,"76":6,"77":7,"78":8,"79":9,"80":10,"81":1,"82":2,"83":3,"84":4,"85":5,"86":6,"87":7,"88":8,"89":9,"90":10,"91":1,"92":2,"93":3,"94":4,"95":5,"96":6,"97":7,"98":8,"99":9,"100":10},"y":{"101":11,"102":0,"1":10,"2":10,"3":10,"4":10,"5":10,"6":10,"7":10,"8":10,"9":10,"10":10,"11":9,"12":9,"13":9,"14":9,"15":9,"16":9,"17":9,"18":9,"19":9,"20":9,"21":8,"22":8,"23":8,"24":8,"25":8,"26":8,"27":8,"28":8,"29":8,"30":8,"31":7,"32":7,"33":7,"34":7,"35":7,"36":7,"37":7,"38":7,"39":7,"40":7,"41":6,"42":6,"43":6,"44":6,"45":6,"46":6,"47":6,"48":6,"49":6,"50":6,"51":5,"52":5,"53":5,"54":5,"55":5,"56":5,"57":5,"58":5,"59":5,"60":5,"61":4,"62":4,"63":4,"64":4,"65":4,"66":4,"67":4,"68":4,"69":4,"70":4,"71":3,"72":3,"73":3,"74":3,"75":3,"76":3,"77":3,"78":3,"79":3,"80":3,"81":2,"82":2,"83":2,"84":2,"85":2,"86":2,"87":2,"88":2,"89":2,"90":2,"91":1,"92":1,"93":1,"94":1,"95":1,"96":1,"97":1,"98":1,"99":1,"100":1}}""")
    return DS_model
